FirebaseCoreWatchos class

watchOS implementation of FirebasePlatform.

Inheritance
  • Object
  • PlatformInterface
  • FirebasePlatform
  • FirebaseCoreWatchos

Constructors

FirebaseCoreWatchos()

Properties

apps → List<FirebaseAppPlatform>
Returns all initialized FirebaseApp instances.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

app([String name = defaultFirebaseAppName]) → FirebaseAppPlatform
Returns a Firebase app with the given name.
override
initializeApp({String? name, FirebaseOptions? options}) → Future<FirebaseAppPlatform>
Initializes a new FirebaseApp with the given name and FirebaseOptions.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

bindingsOverride ↔ FirebaseCoreWatchosBindings?
Test hook: set before first use to replace the FFI bindings.
getter/setter pair

Static Methods

registerWith() → void
Registers this implementation as the default firebase_core platform implementation on watchOS.